@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //------------------------------------------------------------------------------
-// $Id: CommonUtils.cpp,v 1.9 2005/12/17 19:53:29 vlg Exp $
+// $Id: CommonUtils.cpp,v 1.10 2006/07/20 02:30:53 vlg Exp $
 //------------------------------------------------------------------------------
 //                          CommonUtils.cpp
 //------------------------------------------------------------------------------
@@ -16,10 +16,16 @@
 #include <string.h>
 
 #include <stdlib.h>
-#include <pwd.h>
+
 #include <ctype.h>
 #include <unistd.h>				// getcwd(3)
 
+#ifdef WIN32
+static char *home_dir = ".";	/* we feel (no|every)where at home */
+#else
+#    include <pwd.h>
+#endif
+
 #include "assa/Logger.h"
 #include "assa/CommonUtils.h"
 
@@ -139,12 +145,17 @@ strenv (const char* in)
 				while (*in) *lp++ = *in++;
 				*lp = 0;
 			}
+#ifdef WIN32
+            strcpy (ret, home_dir);
+            r += strlen (ret);
+#else
 			// lookup user's home directory in /etc/passwd file
 			struct passwd* p = getpwnam (lname); 
 			if ( p ) {
 				strcpy (ret, p->pw_dir ? p->pw_dir : "");
 				r += strlen (ret);
 			}
+#endif
 		}
     }
 
