@@ -2,7 +2,7 @@
 //------------------------------------------------------------------------------
 //                              Logger_Impl.h
 //------------------------------------------------------------------------------
-// $Id: Logger_Impl.h,v 1.8 2006/03/14 15:51:16 vlg Exp $
+// $Id: Logger_Impl.h,v 1.9 2006/07/20 02:30:54 vlg Exp $
 //------------------------------------------------------------------------------
 //  Copyright (c) 2001 by Vladislav Grinchenko
 //
@@ -21,19 +21,121 @@
 #include <sys/varargs.h>		// va_list
 #endif
 
-#if defined (__CYGWIN32__) || defined (__NetBSD__)
+#if defined (__CYGWIN32__) || defined (__NetBSD__) || defined (WIN32)
 # include <stdarg.h>
 #endif
 
+#if defined(WIN32)
+#    include <winsock2.h>		/* select(3) */
+#endif
+
+/* Also defined in winsock.h, winsock2.h, gmon.h and in cygwin's sys/types 
+*/
+#if !defined ( _BSDTYPES_DEFINED )
+
+typedef unsigned char	u_char;
+typedef unsigned short	u_short;
+typedef unsigned int	u_int;
+typedef unsigned long	u_long;
+
+#define _BSDTYPES_DEFINED
+
+#endif /* ! def _BSDTYPES_DEFINED  */
+
 using std::string;
 using std::ostream;
 
 #include "assa/LogMask.h"
 
+/** Sort out WIN32/mingw oddities
+ */
+#if defined (WIN32)
+
+typedef SOCKET handler_t;
+#define BAD_HANDLER INVALID_SOCKET
+
+/** Map win32 error names
+ */
+#define EINPROGRESS   WSAEINPROGRESS   /* A blocking Winsock call is in
+                                        * progress, or the service provider
+                                        * is still process a callback function.
+										*/
+#define EWOULDBLOCK   WSAEWOULDBLOCK   /* The socket is marked as nonblocking
+										* and the connection cannot be completed
+										* immediately.
+										*/
+#define EISCONN       WSAEISCONN
+
+#define ENOTSOCK      WSAENOTSOCK      /* The descriptor is not a socket.
+										*/
+#define ECONNREFUSED  WSAECONNREFUSED  /* The attempt to connect was
+										* forcefully rejected.
+										*/
+#define ETIMEDOUT     WSAETIMEDOUT     /* An attempt to connect timed out
+										* without establishing connection.
+										*/
+#else    /*--- POSIX ---*/
+
+#define BAD_HANDLER -1
+typedef int handler_t;
+
+#endif	// ifdef WIN32
+
+
 namespace ASSA {
 
 class Reactor;
 
+//---------------------------------------------------------------------------
+// Utilities that don't fit anywhere else
+//---------------------------------------------------------------------------
+
+	/** Detect socket() error in a portable way.
+	 *
+	 *  @return true if socket is in valid range; 
+	 *          false otherwise.
+	 */
+	inline bool is_valid_handler (handler_t socket_) 
+	{
+		return (socket_ != BAD_HANDLER);
+	}
+
+	/** Set socket descriptor to invalid value in a portable way.
+	 *  socket_ is set to the value out of valid range.
+	 */
+	inline void disable_handler (handler_t& socket_)
+	{
+		socket_ = BAD_HANDLER;
+	}
+
+	/** Fetch error number in a portable way.
+	 */
+	inline int get_errno ()
+	{
+		int myerrno;
+#if defined (WIN32)
+		myerrno = WSAGetLastError ();
+#else
+		myerrno = errno;
+#endif
+		return myerrno;
+	}		
+
+	/** Set error number in a portable way.
+	 */
+	inline void set_errno (int new_errno_)
+	{
+#if defined (WIN32)
+        WSASetLastError (new_errno_); 
+#else
+		errno = new_errno_;
+#endif
+	}		
+
+//---------------------------------------------------------------------------
+// Class Logger_Impl
+//---------------------------------------------------------------------------
+
 class Logger_Impl {
 public:
     /** 
