@@ -2,7 +2,7 @@
 //------------------------------------------------------------------------------
 //                          Reactor.cpp
 //------------------------------------------------------------------------------
-//  Copyright (C) 1997-2002,2005,2006  Vladislav Grinchenko
+//  Copyright (C) 1997-2002,2005-2007  Vladislav Grinchenko
 //
 //  This library is free software; you can redistribute it and/or
 //  modify it under the terms of the GNU Library General Public
@@ -176,13 +176,8 @@ removeHandler (EventHandler* eh_, EventType event_)
 
     bool ret = false;
     handler_t fd;
-    handler_t rfdmax;
-    handler_t wfdmax;
-    handler_t efdmax;
 	Fd2Eh_Map_Iter iter;
 
-	rfdmax = wfdmax = efdmax = 0;
-
 	if (eh_ == NULL) {
 		return false;
 	}
@@ -202,7 +197,6 @@ removeHandler (EventHandler* eh_, EventType event_)
 				ret = true;
 				break;
 			}
-			rfdmax = fd;
 			iter++;
 		}
 	} 
@@ -217,7 +211,6 @@ removeHandler (EventHandler* eh_, EventType event_)
 				ret = true;
 				break;
 			}
-			wfdmax = fd;
 			iter++;
 		}
 	}
@@ -232,7 +225,6 @@ removeHandler (EventHandler* eh_, EventType event_)
 				ret = true;
 				break;
 			}
-			efdmax = fd;
 			iter++;
 		}
 	}
@@ -242,7 +234,7 @@ removeHandler (EventHandler* eh_, EventType event_)
 		eh_->handle_close (fd);
 	}
 
-	adjust_maxfdp1 (fd, rfdmax, wfdmax, efdmax);
+	adjust_maxfdp1 (fd);
 
     DL((REACT,"Modifies waitSet:\n"));
     m_waitSet.dump ();
@@ -260,12 +252,6 @@ removeIOHandler (handler_t fd_)
 	EventHandler*  ehp = NULL;
 	Fd2Eh_Map_Iter iter;
 
-    handler_t      rfdmax;
-    handler_t      wfdmax;
-    handler_t      efdmax;
-
-	rfdmax = wfdmax = efdmax = 0;
-
     Assure_return (ASSA::is_valid_handler (fd_));
 
     DL((REACT,"Removing handler for fd=%d\n",fd_));
@@ -283,7 +269,6 @@ removeIOHandler (handler_t fd_)
 		if (m_readSet.size () > 0) {
 			iter = m_readSet.end ();
 			iter--;
-			rfdmax = (*iter).first;
 		}
 		ret = true;
 	}
@@ -297,7 +282,6 @@ removeIOHandler (handler_t fd_)
 		if (m_writeSet.size () > 0) {
 			iter = m_writeSet.end ();
 			iter--;
-			wfdmax = (*iter).first;
 		}
 		ret = true;
 	}
@@ -311,7 +295,6 @@ removeIOHandler (handler_t fd_)
 		if (m_exceptSet.size () > 0) {
 			iter = m_exceptSet.end ();
 			iter--;
-			efdmax = (*iter).first;
 		}
 		ret = true;
 	}
@@ -321,7 +304,7 @@ removeIOHandler (handler_t fd_)
 		ehp->handle_close (fd_);
 	}
 
-	adjust_maxfdp1 (fd_, rfdmax, wfdmax, efdmax);
+	adjust_maxfdp1 (fd_);
 
     DL((REACT,"Modifies waitSet:\n"));
     m_waitSet.dump ();
@@ -715,18 +698,15 @@ stopReactor (void)
  */
 void
 Reactor::
-adjust_maxfdp1 (handler_t fd_, 
-				handler_t rmax_, 
-				handler_t wmax_, 
-				handler_t emax_)
+adjust_maxfdp1 (handler_t fd_)
 {
 #if !defined (WIN32)  /* POSIX */
 
     trace_with_mask("Reactor::adjust_maxfdp1", REACTTRACE);
 
-	if (m_maxfd_plus1 == fd_ + 1) {
-		m_maxfd_plus1 = std::max (rmax_, std::max (wmax_, emax_));
-
+	if (m_maxfd_plus1 == fd_ + 1) 
+	{
+		m_maxfd_plus1 = m_waitSet.max_fd () + 1;
 		DL((REACT,"maxfd+1 adjusted to %d\n", m_maxfd_plus1));
 	}
 #endif
