@@ -38,6 +38,8 @@
  *      Public Domain.  Distribution Unlimited.
  */
 
+#if !defined (WIN32)
+
 #define BSD43
 /* #define BSD42 */
 /* #define BSD41a */
@@ -178,8 +180,16 @@ sigpipe(int)
 }
 #endif
 
+#endif /* !defined WIN32 */
+
+/*----------------------------------------------------------------------------
+ * MAIN
+ *----------------------------------------------------------------------------*/
 int main (int argc, char** argv)
 {
+
+#if !defined (WIN32)
+
     unsigned long addr_tmp;
     int c;
     
@@ -470,8 +480,14 @@ int main (int argc, char** argv)
  usage:
     fprintf(stderr,Usage);
     exit(1);
+
+#endif /* !defined WIN32 */
+
+	return 0;
 }
 
+#if !defined (WIN32)
+
 void
 err (char* s)
 {
@@ -867,3 +883,5 @@ mread(int /* fd */, register char *bufp, unsigned n)
 
     return((int)count);
 }
+
+#endif /* !defined WIN32 */
